#!/bin/bash

echo "##########################################################";
echo "#####            TRX Engine  Installation           ######";
echo "##########################################################";
date
printenv
whoami
pwd
echo "##########################################################";

echo "Verifying required files...";

if [ ! -d /TRXENGINE ]; then
    echo "Verifying TRXENGINE directory [MISSING]";
    exit 1; 
else
    echo "Verifying TRXENGINE directory [OK]";
fi

if [ ! -d /TRXENGINE/licence ]; then
    echo "Verifying licence directory [MISSING]";
    exit 1; 
else
    echo "Verifying licence directory [OK]";
fi

if [ ! -d /TRXENGINE/mfs ]; then
    echo "Verifying mfs directory [MISSING]";
    exit 1; 
else
    echo "Verifying mfs directory [OK]";
fi

if [ ! -d /TRXENGINE/cobol ]; then
    echo "Verifying cobol directory [MISSING]";
    exit 1; 
else
    echo "Verifying cobol directory [OK]";
fi

if [ ! -d /TRXENGINE/elastic_cobol ]; then
    echo "Verifying elastic_cobol directory [MISSING]";
    exit 1; 
else
    echo "Verifying elastic_cobol directory [OK]";
fi

if [ -e /TRXENGINE/licence/trx-engine-heirloom.licence ]; then
    echo "/TRXENGINE/licence/trx-engine-heirloom.licence [OK]";
else
    echo "/TRXENGINE/licence/trx-engine-heirloom.licence [MISSING]";
    exit 1;
fi

if [ -e /TRXENGINE/licence/elasticcobol.properties ]; then
    echo "/TRXENGINE/licence/elasticcobol.properties [OK]";
else
    echo "/TRXENGINE/licence/elasticcobol.properties [MISSING]";
    exit 1;
fi

cd /TRXENGINE/TRXHeirloom_V*
mkdir -p tmwebconfig/webapps
ls -l
echo "##########################################################";

echo "Verifying extracted application...";

if [ -e TRXHeirloom.jar ]; then
    echo "TRXHeirloom.jar [OK]";
else
    echo "TRXHeirloom.jar [MISSING]";
    exit 1;
fi

echo "##########################################################";

echo "Using provided licence file..."
rm -f trx-engine-heirloom.licence
cp /TRXENGINE/licence/trx-engine-heirloom.licence .

echo "Using provided elasticcobol licence file..."
cp /TRXENGINE/licence/elasticcobol.properties /root/elasticcobol.properties

echo "##########################################################";

echo "Setting the loglevel..."

if [[ -n $LOGLEVEL ]]; then
	sed -i "s/.level=WARNING/.level=$LOGLEVEL/g"  logging.properties
fi

echo "Setting paths..."
sed -i "s/MfsPath=.*/MfsPath=\/TRXENGINE\/mfs/g"  config.properties
sed -i "s/CobolPath=.*/CobolPath=\/TRXENGINE\/cobol/g"  config.properties
sed -i "s/EcobolLibPath=.*/EcobolLibPath=\/TRXENGINE\/elastic_cobol/g"  config.properties

echo "Setting parameter..."
sed -i "s/TerminalPort=.*/TerminalPort=$TERMINALPORT/g"  config.properties
sed -i "s/ImsConnectPort=.*/ImsConnectPort=$IMSCONNECTPORT/g"  config.properties
sed -i "s/WebConfigPort=.*/WebConfigPort=$WEBCONFIGPORT/g"  config.properties
sed -i "s/db-type=.*/db-type=$DBTYPE/g"  config.properties
sed -i "s/db-server=.*/db-server=$DBSERVER/g"  config.properties
sed -i "s/db-port=.*/db-port=$DBPORT/g"  config.properties
sed -i "s/db-name=.*/db-name=$DBNAME/g"  config.properties
sed -i "s/db-user=.*/db-user=$DBUSER/g"  config.properties
sed -i "s/db-pwd=.*/db-pwd=$DBPWD/g"  config.properties
sed -i "s/db-schema=.*/db-schema=$DBSCHEMA/g"  config.properties

echo "##########################################################";

echo "Installation [FINISHED]"

echo "##########################################################";
echo "Starting TRX Engine..."   
./trx-tm-server.sh





