#!/bin/bash

echo "######################################################################################";
echo "#####             TRX-Engine - TM-Server start/stop script for Linux            ######";
echo "#####                                                                           ######";
echo "######################################################################################";
date
echo "######################################################################################";

if [ -z "$1" ]
  then
  
    echo "No argument supplied! Using the default java installation!";
    echo "To use a specific Java installation please append the path to your Java installation. Example:";
    echo "./trx-tm-server.sh /opt/IBM/db2/V10/java/jdk64";
    echo "######################################################################################";
    
    echo " ";
    echo "Using Default Java installation...";
    _java="java"
    
  else 
  
    echo " ";
    echo "Using Specific Java installation...";
    if [[ -x "${1}/bin/java" ]]  
      then  
        _java="${1}/bin/java"
    else
        echo "Java could not be verified! Please verify the path to the Java installation you entered.";
        exit 1;
    fi
    
fi

echo " ";
echo "Verifying Java installation...";
    
version=$("$_java" -version 2>&1 | head -1 | cut -d'"' -f2 | sed '/^1\./s///' | cut -d'.' -f1)
if [ "$version" = "8" ] || [ "$version" = "9" ]; then
    echo "Installed Java JDK has version $version [OK]"
else 
    echo "Installed Java JDK has version $version [FAILED]"
    echo "Please provide a Java JDK version 1.8!";
    exit 1;
fi
echo "######################################################################################";
echo "Preparation..."; 

"$_java" -jar -Djava.util.logging.config.file=logging.properties -Dde.itgain.gw3270.config.file=config.properties TRXHeirloom.jar createEcobolLink

echo "Starting the application..."; 

"$_java" -jar -Djava.util.logging.config.file=logging.properties -Dde.itgain.gw3270.config.file=config.properties -agentlib:jdwp=transport=dt_socket,address=8000,server=y,suspend=n TRXHeirloom.jar